module GitPunch
  class Plugin < Thor
    include Thor::Actions
    include MediaConfig

    def self.source_root
      GitPunch.template_path
    end

    desc :init, "Install GitPunch on this repo."
    def init
      install_configuration!

      say %{
        We strongly urge you to `gem install guard-live-set && guard init live-set`
        so you can automatically keep your Live set changes in Git.
      } if project.live? && !project.has_guard_installed?
    end

  private
    def repo
      @current_repository ||= Repository.current!
    end

    def project
      @project ||= Project.detect!
    end

    def install_configuration!
      run "git config punch.username '#{note_punch_username}'"
      copy_file 'post-commit.sh', '.git/hooks/post-commit'
      template 'gitattributes.erb', '.gitattributes'
      template 'gitignore.erb', '.gitignore'
      system 'cp .git/config .git/config.backup' # silently back up gitconfig
      insert_into_file '.git/config', git_media_config, before: '[punch]'
    end

    def note_punch_username
      @user_name ||= if configured_user_name.empty?
        ask 'What is your NotePunch username?'
      else
        configured_user_name
      end
    end

    def configured_user_name
      @user_name_from_gitconfig ||= `git config punch.username`.strip
    end
  end
end
