# Represents your current project and basically figures out its type.
module GitPunch
  class Project
    EXTENSIONS = {
      logic: "*.logic",
      live: "*.als"
    }

    def initialize with_root_directory
      @root = with_root_directory
    end

    def self.detect!
      new in_current_directory
    end

    def has_guard_installed?
      not guard_command.nil?
    end

  protected
    def method_missing name, *args
      if "#{name}" =~ /\?$/
        is_project? "#{name}".gsub(/\?/, '').to_sym
      else
        super name, args
      end
    end

  private
    def is_project? name
      raise "project type '#{name}' not supported" \
        unless EXTENSIONS.keys.include? name

      extension_matcher = EXTENSIONS[name]
      Dir[extension_matcher].any?
    end

    def guard_command
      system 'guard'
    end

    def self.in_current_directory
      File.dirname File.expand_path(__FILE__)
    end
  end
end
