require 'json'

module GitPunch
  class User
    EVERYTHING_BUT_THE_OWNER = /(git|http|https):\/\/notepunch\.com(\:|\/)\.git/
    attr_reader :token

    def initialize from_options={}
      from_options.each do |key,value|
        instance_variable_set "@#{key}", value
      end
    end

    def name
      @name.strip
    end

    def present?
      not name.empty?
    end

    def self.from_origin
      remote = `git remote show origin`
      raise "No origin configured" if remote.empty?
      line = remote.split("\n").select { |l| l =~ /Fetch URL/ }.first
      owner = if line =~ /\A(.*)\:(.*)\.git\Z/
        $2.split('/')[-2]
      else
        ""
      end

      new name: owner
    end

    def self.from_config
      username = `git config punch.username`
      api_key = `git config punch.token`

      new name: username, token: api_key
    end

    def credentials
      {
        username: name,
        password: token
      }
    end
  end
end
